accum

Function accum 

pub fn accum(xn: impl Into<ElemNode>, reset: impl Into<ElemNode>) -> Node
el.accum(xn, reset)

Outputs a continuous and running sum over the samples in the input signal xn. This value can grow very large, very quickly, so use with care. The second argument reset is a pulse train signal which resets the running sum to 0 on each rising edge.