env

Function env 

pub fn env(
    atk_pole: impl Into<ElemNode>,
    rel_pole: impl Into<ElemNode>,
    x: impl Into<ElemNode>,
) -> Node
el.env(atkPole, relPole, x)

A one-pole envelope follower with different attack and release times. This is similar to el.pole(p, el.abs(x)) in implementation. Expects three children: attack pole, release pole, and the signal to monitor.