sample

Function sample 

pub fn sample(
    props: Value,
    trigger: impl Into<ElemNode>,
    rate: impl Into<ElemNode>,
) -> Node
Loads a sample from the virtual file system and triggers its playback on the rising edge of an incoming pulse train. Expects a props arg and then two children: first the pulse train to trigger playback, and second a signal which continuously directs the sample’s playback rate.