Instruction

Enum Instruction 

pub enum Instruction {
    CreateNode {
        node_id: NodeId,
        node_type: String,
    },
    SetProperty {
        node_id: NodeId,
        property: String,
        value: Value,
    },
    AppendChild {
        parent_id: NodeId,
        child_id: NodeId,
        child_output_channel: i32,
    },
    ActivateRoots {
        roots: Vec<NodeId>,
    },
    CommitUpdates,
}
Instruction types and the runtime wrapper. Instruction supported by the current wrapper surface.

Variants



CreateNode

Create a runtime node with the given identifier and type.

Fields

node_id: NodeId

Node identifier assigned by the caller.

node_type: String

Native node type name.



SetProperty

Set a property on an existing node.

Fields

node_id: NodeId

Target node identifier.

property: String

Property name.

value: Value

JSON value to assign to the property.



AppendChild

Append one node as a child of another node.

Fields

parent_id: NodeId

Parent node identifier.

child_id: NodeId

Child node identifier.

child_output_channel: i32

Output channel index on the child node.



ActivateRoots

Activate the provided root nodes.

Fields

roots: Vec<NodeId>

Root node identifiers.



CommitUpdates

Commit a pending set of runtime updates.