pub fn metro(props: Option<Value>) -> NodeExpand description
el.metro(props)
Only available in the WASM-based renderers. You may extend the runtime in your own integration with a similar processor if you like, but it is not provided by default.
Emits a pulse train signal much like el.train, alternating from 0
to 1 at a given rate. Importantly, the el.metro node is used for
synchronized train signals, and will emit an event through the core
renderer’s interface on each rising edge of its output signal.
Props:
name: identifies a metro node by nameinterval: metronome period in milliseconds