pub fn sample(props: Value, gate: impl Into<ElemNode>) -> Vec<Node>Expand description
Loads a sample from the virtual file system and triggers its playback
on the rising edge of an incoming pulse train. Expects a props arg and
then one child, t, the pulse train to trigger playback.
This node is nearly identical to el.sample, except that mc.sample
supports multi-channel buffers through the virtual file system and
produces multi-channel output. The return value is an array containing
the individual channel signals you want to address.