pub enum Instruction {
CreateNode {
node_id: NodeId,
node_type: String,
},
SetProperty {
node_id: NodeId,
property: String,
value: Value,
},
AppendChild {
parent_id: NodeId,
child_id: NodeId,
child_output_channel: i32,
},
ActivateRoots {
roots: Vec<NodeId>,
},
CommitUpdates,
}Expand description
Instruction types and the runtime wrapper. Instruction supported by the current wrapper surface.
Variants
CreateNode
Create a runtime node with the given identifier and type.
Fields
SetProperty
Set a property on an existing node.
Fields
AppendChild
Append one node as a child of another node.
Fields
ActivateRoots
Activate the provided root nodes.
CommitUpdates
Commit a pending set of runtime updates.